import React from 'react';

import { InputWithClipboard } from './input-with-clipboard';

let wrapper;

jest.useFakeTimers();

describe('<InputWithClipboard />', () => {
  wrapper = shallow(<InputWithClipboard value="qwe123" />);
  const { setTimeout, clearTimeout } = window;

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  describe('setTimeout && clearTimeout', () => {
    test('componentWillUnmount should not trigger `clearTimeout`', () => {
      wrapper.instance().componentWillUnmount();
      expect(clearTimeout).toHaveBeenCalledTimes(0);
    });

    test('`copy` should change state prop `copied` to true', () => {
      wrapper.instance().copy();
      expect(wrapper.instance().state.copied).toEqual(true);
      expect(setTimeout).toHaveBeenCalledTimes(1);
    });

    test('componentWillUnmount should trigger `clearTimeout`', () => {
      wrapper.instance().componentWillUnmount();
      expect(clearTimeout).toHaveBeenCalledTimes(1);
    });
  });

  test('`resetCopy` should change state prop `copied` to false', () => {
    wrapper.instance().resetCopy();
    expect(wrapper.instance().state.copied).toEqual(false);
  });

  test('if `isLoading` is true', () => {
    wrapper.setProps({ isLoading: true });
    expect(wrapper).toMatchSnapshot();
  });
});
