import React from 'react';
import Button from 'reactstrap/lib/Button';

import { CalcAmount } from './calc-amount';

import { CHAR_CODES } from '../../../constants';

const props = {
  rate: '0.2',
  ethValue: '2',
  scrValue: '233',
  maxAmount: '1200',
  onEthChange: jest.fn(),
  onScrChange: jest.fn(),
  isEthLoading: false,
  isScrLoading: false,
  onContinueClick: jest.fn(),
  isMaxAmountLoading: false,
};
const evt = {
  which: undefined,
  keyCode: CHAR_CODES.NINE,
  preventDefault: jest.fn(),
};
let wrapper;

describe('<CalcAmount />', () => {
  wrapper = shallow(<CalcAmount {...props} />);

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  describe('onKeyPress', () => {
    test('should not trigger `preventDefault`', () => {
      wrapper.instance().onKeyPress(evt);
      evt.keyCode = 1;
      wrapper.instance().onKeyPress(evt);
      expect(evt.preventDefault).toHaveBeenCalledTimes(0);
    });

    test('should trigger `preventDefault`', () => {
      evt.keyCode = 66;
      wrapper.instance().onKeyPress(evt);
      evt.keyCode = 47;
      wrapper.instance().onKeyPress(evt);
      expect(evt.preventDefault).toHaveBeenCalledTimes(2);
    });
  });

  describe('ethChangeHandler', () => {
    test('should not trigger `onEthChange` prop', () => {
      wrapper.instance().ethChangeHandler({ target: { value: '3.sadas' } });
      expect(props.onEthChange).toHaveBeenCalledTimes(0);
    });

    test('should trigger `onEthChange` prop', () => {
      wrapper.instance().ethChangeHandler({ target: { value: '3.3' } });
      expect(props.onEthChange).toHaveBeenCalledTimes(1);
    });
  });

  describe('scrChangeHandler', () => {
    test('should not trigger `onScrChange` prop', () => {
      wrapper.instance().scrChangeHandler({ target: { value: '3.sadas' } });
      expect(props.onScrChange).toHaveBeenCalledTimes(0);
    });

    test('should trigger `onScrChange` prop', () => {
      wrapper.instance().scrChangeHandler({ target: { value: '3.3' } });
      expect(props.onScrChange).toHaveBeenCalledTimes(1);
    });
  });

  test('should change state value `checked` after trigger `toggleCheck`', () => {
    expect(wrapper.instance().state.checked).toEqual(false);
    wrapper.instance().toggleCheck();
    expect(wrapper.instance().state.checked).toEqual(true);
  });

  test('click on `continue button` should trigger `onContinueClick` prop', () => {
    wrapper.find(Button).simulate('click');
    expect(props.onContinueClick).toHaveBeenCalledTimes(1);
  });

  test('should be preloader for maxAmount if isMaxAmountLoading = true', () => {
    wrapper.setProps({ isMaxAmountLoading: true });
    expect(wrapper).toMatchSnapshot();
  });

  test('should be preloader for rate if rate = false and isEthLoading/isScrLoading = true', () => {
    wrapper.setProps({ rate: null, isScrLoading: true });
    expect(wrapper).toMatchSnapshot();
  });
});
